# 计算表达式参考手册

## 支持的常数
* pi
* π
* e
* φ

## 支持的运算符

* 加法运算: 2 + 2
* 减法运算: 2 - 2
* 乘法运算: 2 * 2
* 除法运算: 2 / 2
* 次幂运算: 2 ^ 2
* 正负符号: +2, -2
* 取模运算: 2 % 2

## 支持的函数

* abs: 绝对值
* acos: 反余弦
* asin: 反正弦
* atan: 反正切
* cbrt: 立方根
* ceil: 向上取整
* cos: 余弦
* cosh: 双曲余弦
* exp: 指数次幂，即e的x次幂 (e^x)
* floor: 向下取整
* log: 取e为底的对数
* log10: 取10为底的对数
* log2: 取2为底的对数
* sin: 正弦
* sinh: 双曲正弦
* sqrt: 平方根
* tan: 正切
* tanh: 双曲正切
* signum: 取符号运算，大于0时为1，小于0时为-1，等于0时为0

```
以下式子表示取-10的绝对值

value = abs(-10)
```

## 拓展的运算符

布尔运算，如果为真则为1，否则为0，与加法乘法配合使用可实现离散函数的效果
* ==
* !=
* &gt;=
* &lt;=
* &gt;
* &lt;

布尔运算的优先级很低，使用时最好加上括号

```
以下的表达式实现了一个离散函数
x > 15 时为 15
x < -3 时为 -3
其余情况为 x 本身

v1 = (x > 15) * 15
v2 = (x < -3) * (-3)
v3 = ((x <= 15) * (x >= -3)) * x
value = v1 + v2 + v3
```

## 软件中可能使用到的变量

| 变量名 | 单位 | 数据名称 |
|:-----:|:----:|:------:|
| B | rps | Va涡轮转速 |
| BOD | mm | 叶片外径 |
| Bg |  | 地层气体积系数 |
| Bgr | 1/x | 地层气体积系数倒数 |
| Bo |  | 地层油体积系数 |
| Bw |  | 地层水体积系数 |
| Cog |  | 地层气压缩系数 |
| Cv |  | 速度校正系数 |
| Cw |  | 地层水压缩系数 |
| DOD | mm | 仪器外径 |
| FDen | g/cm³ | 流体密度 |
| FlCb |  | Cb |
| FlCg |  | Cg |
| FlCo |  | Co |
| FlDelta | dyn/cm | 流体间表面张力 |
| FlVt | m/min | 漂移速度 |
| GDenG | 相对 | 地面气密度 |
| GDenO | g/ml | 地面油密度 |
| GPre | MPa | 地面压力 |
| GQg | m³/d | 日产气量 |
| GQo | t/d | 日产油量 |
| GQw | t/d | 日产水量 |
| GTemp | °C | 地面温度 |
| Hydr |  | 持水率计 |
| K |  | K值 |
| PID | mm | 管柱内径 |
| Pb | MPa | 泡点压力 |
| Pg | m³/d | Pg |
| Po | m³/d | Po |
| Pw | m³/d | Pw |
| Qg | m³/d | Qg |
| Qo | m³/d | Qo |
| Qw | m³/d | Qw |
| Rf | m³/m³ | 游离油气比 |
| Rp | m³/m³ | 生产油气比 |
| Rs | m³/m³ | 溶解油气比 |
| Rsw | m³/m³ | 溶解气水比 |
| SVs | m/min | 滑脱速度 |
| UDenG | g/cm³ | 地层气密度 |
| UDenO | g/cm³ | 地层油密度 |
| UDenW | g/cm³ | 地层水密度 |
| UPre | MPa | 地层压力 |
| USali | ppm | 地层水矿化度 |
| UTemp | °C | 地层温度 |
| UViscG | cP | 地层气粘度 |
| UViscO | cP | 地层油粘度 |
| UViscW | cP | 地层水粘度 |
| Va | m/min | 视速度 |
| Vsg | m/min | 气表观速度 |
| Vso | m/min | 油表观速度 |
| Vsw | m/min | 水表观速度 |
| Yg |  | 持气率 |
| Yo |  | 持油率 |
| Yw |  | 持水率 |
| Zg |  | 气体偏差因子 |